#
# spec file for package libmatekbd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define typelib  typelib-1_0-Matekbd-1_0
%define _version 1.26
%define sover    4
Name:           libmatekbd
Version:        1.26.1
Release:        1.1
Summary:        MATE Desktop keyboard configuration libraries
License:        LGPL-2.1-or-later
Group:          Development/Libraries/X11
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxklavier) >= 5.2
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(x11)
%glib2_gsettings_schema_requires

%description
This package provides libmatekdb, an API to manage the keyboard in
MATE Desktop applications.

%package -n matekbd-common
Summary:        MATE Desktop keyboard configuration common files
Group:          System/Libraries

%description -n matekbd-common
This package provides libmatekdb, an API to manage the keyboard in
MATE Desktop applications.

%package -n %{name}%{sover}
Summary:        MATE Desktop keyboard configuration shared libraries
Group:          System/Libraries
Requires:       matekbd-common
Recommends:     %{name}-lang
Provides:       %{name} = %{version}
# libmatekbd with a wrong sover was last used in openSUSE Leap 42.1.
Obsoletes:      %{name}1 < %{version}

%description -n %{name}%{sover}
This package provides libmatekdb, an API to manage the keyboard in
MATE Desktop applications.

%package devel
Summary:        MATE Desktop keyboard configuration development files
Group:          Development/Libraries/X11
Requires:       %{name}%{sover} = %{version}
Requires:       matekbd-common = %{version}

%description devel
This package provides libmatekdb, an API to manage the keyboard in
MATE Desktop applications.

%package -n %{typelib}
Summary:        MATE Desktop keyboard configuration typelib

%description -n %{typelib}
This package provides libmatekdb, an API to manage the keyboard in
MATE Desktop applications.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{sover} -p /sbin/ldconfig

%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc AUTHORS ChangeLog
%{_libdir}/*.so.%{sover}*

%files -n matekbd-common
%{_datadir}/glib-2.0/schemas/*.xml

%files -n %{typelib}
%{_libdir}/girepository-1.0/Matekbd-1.0.typelib

%files devel
%license COPYING
%doc AUTHORS ChangeLog
%{_includedir}/%{name}/
%{_datadir}/gir-1.0/Matekbd-1.0.gir
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files lang -f %{name}.lang

%changelog
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * matekbd-keyboard-drawing: Fix memory leaks.
  * Update translations.
* Tue Aug 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * tx: sync with transifex
  * build: show package name and version in configure summary
  * build: set GETTEXT_PACKAGE=AC_PACKAGE_NAME
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * build: Silent build warnings for distcheck.
  * Reduce the font size of the key names on keyboard layout
    display.
  * matekbd-keyboard-drawing: i18n symbolic names.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * build: Add configuration summary.
  * Use gresources for UI files.
  * matekbd-keyboard-config: Value stored to "clen" is never read.
  * matekbd-util: Local variables shadow outer variables.
  * matekbd-keyboard-drawing: Uninitialised structure member.
  * matekbd-config-private: Avoid redundant redeclarations.
  * Migrate from intltool to gettext.
  * Update translations.
- Drop support for old openSUSE versions.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to 1.23.0:
  * Update translations
- remove patches:
  * libmatekbd-gtk-3.20.patch: we don't support gtk3.20 anymore
- BuildRequire gtk3 >= 3.22
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Rename g_strv_equal to matekbd_strv_equal.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Update translations.
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Use GdkScreen resolution for font in keyboard status
    notification icon.
  * Update translations.
* Fri Mar 16 2018 crrodriguez@opensuse.org
- Package should buildrequire pkgconfig(x11, pango, cairo)
  to have a complete list of requirements.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * matekbd-status: Fix the Gdk-CRITICAL warning on creating the
    status bar icon.
  * Avoid deprecated gdk_screen_get_monitor_(),
    gdk_screen_get_width/height(), gdk_screen_get_number()
    functions.
  * matekbd-indicator: Don't expand.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * Update translations.
- Add libmatekbd-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
* Mon Apr 10 2017 sor.alexei@meowr.ru
- Update to version 1.18.2 (changes since 1.18.0):
  * matekbd-indicator: Do not use deprecated gdk_cairo_create.
  * A fix for a strange GtkIconInfo behaviour.
  * matekbd-indicator: Do not use deprecated GtkAlignment.
  * keyboard-drawing: Set a CSS name matekbd-keyboard-drawing.
  * Slightly increase the font size for the key labels.
  * matekbd-keyboard-drawing: Don't unset double buffering.
  * matekbd-keyboard-drawing: Handle XkbGetKeyboard() failing.
  * matekbd-keyboard-drawing: Prevent gtk+ keynav from taking
    focus away.
  * Fix some introspection warnings.
  * show-layout.ui: Do not use deprecated widgets.
  * UI: Expand kbdraw vertically.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Move to GTK+3 (>= 3.14), drop the GTK+2 code and --with-gtk
    build option.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Require libxklavier 5.2 and use its introspection.
  * GTK+3: Fix some deprecations.
  * distcheck: Explicitly use a currently selected GTK+ version.
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Some more fixes and cleanups.
  * Update translations.
  * Fix Changelog generation.
- Enable GObject Introspection.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Drop MateConf migration script.
  * Reduce introspection build warnings.
  * Fix some Gtk3 deprecations.
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
- Add baselibs.conf.
* Thu Oct 15 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Add GObject introspection.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Layout view/print dialog: remove useless Help button.
  * Layout view/print dialog: some UI fixes.
  * Some GTK+3 fixes.
  * Some more fixes and cleanups.
  * Update translations.
* Wed Oct 14 2015 sor.alexei@meowr.ru
- Fix ABI version.
* Tue Apr 14 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * bugfixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * bugfixes release
* Tue Jan 13 2015 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + fix possible dereference of NULL pointer
  + fix UI load in GTK+3 build
  + update translations
* Sun Jul 13 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + bugfix release
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Sat Feb 15 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + Improved indicator font customization
  + GTK3 support
- Remove useless pkgconfig(gtk-doc) and xz require
* Wed Jan  1 2014 p.drouand@gmail.com
- Update to version 1.6.2
  + improved indicator font customization
  + explicit declaration of internal libxklavier functions
    from lingnomekbd:
    https://git.gnome.org/browse/libgnomekbd/commit/?id=18332fedc6a24e4efeecfdc78a006140c667568a
    https://bugzilla.gnome.org/show_bug.cgi?id=643754
* Fri Sep 20 2013 p.drouand@gmail.com
- Readd Recommends: %%{name}-lang in libmatekbd1 package
* Fri Sep 20 2013 p.drouand@gmail.com
- Remove Recommends: %%{name}-lang and add Provides: %%{name} = %%{version}
  to automatically install lang package with library
* Fri Sep 20 2013 p.drouand@gmail.com
- the library rely on the glib schema to be present; add
  Requires: matekbd-common in libmatekbd1 package that needs
  glib schemas
- Use %%lang_package macro instead of create lang subpackage manually
- Fix library subpackage group to System/Libraries
- libmatekbd package doesn't exist; matekbd-common must recommends
  libmatekbd-lang
* Thu Sep 19 2013 cdenicolo@suse.com
- license update: LGPL-2.1+
  LGPL is "or laterÃÃ".
* Tue Jun 25 2013 johann.luce@wanadoo.fr
- Update to version 1.6.1
  + Fixes to use make dist
  + Fix previous commit typo in schema
  + Add missing keys in GSettings schema
  + Group concensus: just delete unused code; git log stores it
  + Clean up compile, fix bug with handling variants. Closes #8
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + update translations
* Fri Feb  8 2013 nmo.marques@gmail.com
- Update to version 1.5.1
  + now requires automake 1.13
  + fix desktop gschema
  + rename configure
  + minor fixes
- Update license to match release
* Sun Nov 18 2012 nmo.marques@gmail.com
- Add xz to BRs; update contact in RPM changelog and minor spec
  fixes
* Tue Oct  9 2012 nmarques@mate-desktop.org
- Update to version 1.5.0
  + Switch to gsettings (dropped mateconf)
  + Removed old obsolete plugin system for keyboard indicators
- Remove mateconf-2.0 dependencies and macros
- Improve summaries and descriptions
* Sat Sep  8 2012 nmarques@mate-desktop.org
- Copypac to X11:MATE
  + minor cosmetic fixes
* Fri Aug  3 2012 hillwood@linuxfans.org
- Update to version 1.4.0
* Sun Jun 17 2012 nmarques@mate-desktop.org
- Use mateconf macros on .spec and some cleanups
* Sat Jun 16 2012 nmarques@mate-desktop.org
- Update to version 1.2.0
* Fri Dec 30 2011 nmarques@opensuse.org
- Initial package from version 1.1.0
